IDashboardConsoTot class

Annotations
  • @JsonSerializable.new()

Constructors

IDashboardConsoTot({required String Name, required double Qty, required double Base, required double Tax, required double TTC})
const
IDashboardConsoTot.fromJson([Map<String, dynamic>? json])
factory

Properties

Base double
final
hashCode int
The hash code for this object.
no setterinherited
Name String
final
Qty double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Tax double
final
TTC double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited