IR5Delivry class
Delivry Or Take Away Info . **** WORK IN PROGRESS ****
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- Addr → String?
-
Address
final
- Date → String?
-
Date Time Formatted as yyyy-mm-dd
final
- DateTime → String
-
Date Time Formatted as yyyy-mm-dd hh:mm - hh:mm
final
- Flags → int?
-
Flags (Pickup(Bit1=2),Delivry(Bit2=4),...)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- Location → String?
-
Location (CityZone,...)
final
- Memo → String?
-
Free Memo Message.
final
- Msg → String?
-
Free Info Message.
final
- Name → String?
-
Just a Name.
final
- Note → String?
-
Free Note Message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- Tel → String?
-
Tel Number
final
- TicketProdDelay → int?
-
TicketProdDelay x minutes before delivry time
final
- TimeRange → String?
-
Date Time Formatted as hh:mm - hh:mm
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited